#!/bin/bash

tag=$(sed -n 's/^Version:\s\(.*\)$/\1/p' ./*.spec | sed -e 's/^[[:space:]]*//' -e 's/[[:space:]]*$//')
url=$(sed -n 's/^URL:\s\(.*\)$/\1/p' ./*.spec | sed -e 's/^[[:space:]]*//' -e 's/[[:space:]]*$//')
pkgdir=$(basename $url | sed -s 's/\.git$//')

echo "tag: $tag"
echo "URL: $url"
echo "pkgdir: $pkgdir"

set -e

tmp=$(mktemp -d)

trap cleanup EXIT
cleanup() {
    echo Cleaning up...
    set +e
    [ -z "$tmp" -o ! -d "$tmp" ] || rm -rf "$tmp"
}

unset CDPATH
pwd=$(pwd)

pushd "$tmp"
git clone $url
cd $pkgdir
echo Finding git tag
#gittag=$(git show-ref --tags | cut -d' ' -f2 | grep '${tag}$'| sort -nr | head -n1)
gittag=$(git show-ref --tags | cut -d' ' -f2 | grep "${tag}$" )
echo "Git Tag: $gittag"
gitshorttag=$(echo $gittag | cut -d'/' -f3)
echo "Git Short Tag: $gittag"
gitobject=$(git show-ref --tags $gittag -d | grep '\^{}$' | cut -d'^' -f1 | cut -d' ' -f1)
echo "Git Object: $gitobject"
gitorg=$(echo $url | cut -d'/' -f4)
echo "Git Org: $gitorg"
gitrepo=$(echo $url | cut -d'/' -f5 | sed -e 's/\.git$//')
echo "Git Repo: $gitrepo"
newurl=https://raw.githubusercontent.com/${gitorg}/${gitrepo}/${gitshorttag}/test.js
if [ -z $gittag ]; then
	echo "!! No Git tag found"
	exit;
fi
if [ -f "test.js" ]; then
	pushd ${pwd}
	wget ${newurl}
	popd
else
  echo "No testjs file found at $url"
fi
echo "SourceX:	${newurl}"
popd
